;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tao-theme" "20250717.347"
  "This package provides two parametrized uncoloured color themes for Emacs: tao-yin and tao-yang."
  ()
  :url "http://github.com/11111000000/tao-theme-emacs"
  :commit "33c0d44048afe444e7a8aee30fbc101a00453799"
  :revdesc "33c0d44048af"
  :authors '(("Peter Kosov" . "11111000000@email.com"))
  :maintainers '(("Peter Kosov" . "11111000000@email.com")))
